# coding: utf-8
u"""Кастомные поля моделей Django"""


from django.db.models.fields import DecimalField

from educommon.django.db.validators.simple import SingleErrorDecimalValidator
from educommon.utils.misc import cached_property


class SingleErrorDecimalField(DecimalField):

    u"""
    Кастомный класс поля Decimal.

    Переопределяется метод validators для подключения
    SingleErrorDecimalValidator который приводит сообщение об ошибке к единому
    стилю не разделя ошибки по переполнению целой + дробной части и отдельно
    целой.
    """

    @cached_property
    def validators(self):
        u"""
        Переопрелеление стандартного валидатора Decimal.

        :return: Список валидаторов.
        """
        validators = super(SingleErrorDecimalField, self).validators
        validators.pop()
        validators.append(
            SingleErrorDecimalValidator(
                self.max_digits, self.decimal_places
            )
        )
        return validators
